# Duckietown Challenges Runner
[![CircleCI](https://circleci.com/gh/duckietown/duckietown-challenges-runner.svg?style=shield)](https://circleci.com/gh/duckietown/duckietown-challenges-runner) [![Docker Hub](https://img.shields.io/docker/pulls/duckietown/dt-challenges-evaluator.svg)](https://hub.docker.com/r/duckietown/dt-challenges-evaluator)

You should only use this package if `dts challenges evaluate` fails for you.


## Installation

Install with:

    $ pip install -U --user duckietown-challenges-runner
  
## Evaluate remote submission

Help evaluate the Duckietown challenges by running:

    $ dt-challenges-evaluator --continuous
  
## Evaluate locally 

You can also specify a specific submission:

    $ dt-challenges-evaluate-local
    
